summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorManuel Bentele2021-09-03 16:01:55 +0200
committerManuel Bentele2021-09-03 16:01:55 +0200
commit98ce3a2647705b6ea9924836285b1ea0448080fb (patch)
tree7dea1d3237040334c8abcf6fb059c42ee3ad84ed
parent[qemu] Fix path to shared memory file for looking-glass-client (diff)
downloadmltk-98ce3a2647705b6ea9924836285b1ea0448080fb.tar.gz
mltk-98ce3a2647705b6ea9924836285b1ea0448080fb.tar.xz
mltk-98ce3a2647705b6ea9924836285b1ea0448080fb.zip
[qemu] Set default renderer for looking-glass-client to OpenGL
-rw-r--r--core/modules/qemu/runvirt-plugin-qemu/src/main/java/org/openslx/runvirt/viewer/ViewerLookingGlassClient.java6
1 files changed, 4 insertions, 2 deletions
diff --git a/core/modules/qemu/runvirt-plugin-qemu/src/main/java/org/openslx/runvirt/viewer/ViewerLookingGlassClient.java b/core/modules/qemu/runvirt-plugin-qemu/src/main/java/org/openslx/runvirt/viewer/ViewerLookingGlassClient.java
index 666910d4..e625eab3 100644
--- a/core/modules/qemu/runvirt-plugin-qemu/src/main/java/org/openslx/runvirt/viewer/ViewerLookingGlassClient.java
+++ b/core/modules/qemu/runvirt-plugin-qemu/src/main/java/org/openslx/runvirt/viewer/ViewerLookingGlassClient.java
@@ -82,12 +82,13 @@ public class ViewerLookingGlassClient extends Viewer
{
// execute viewer process with arguments:
// in non-debug mode:
// "looking-glass-client app:shmFile=<SHARED-MEM-FILE> win:fullScreen=yes spice:enable=yes spice:host=<SPICE-ADDRESS> spice:port=<SPICE-PORT> win:alerts=no"
// in debug mode:
// "looking-glass-client app:shmFile=<SHARED-MEM-FILE> win:fullScreen=yes spice:enable=yes spice:host=<SPICE-ADDRESS> spice:port=<SPICE-PORT> win:alerts=yes win:showFPS=yes"
final String[] viewerParameters;
if ( this.isDebugEnabled() ) {
viewerParameters = new String[] {
+ "app:renderer=OpenGL",
"app:shmFile=" + "/dev/shm/" + ViewerLookingGlassClient.SHARED_MEMORY_FILENAME,
"win:fullScreen=yes",
"spice:enable=yes",
@@ -96,6 +97,7 @@ public class ViewerLookingGlassClient extends Viewer
"win:alerts=no" };
} else {
viewerParameters = new String[] {
+ "app:renderer=OpenGL",
"app:shmFile=" + "/dev/shm/" + ViewerLookingGlassClient.SHARED_MEMORY_FILENAME,
"win:fullScreen=yes",
"spice:enable=yes",
@@ -82,12 +82,13 @@ public class ViewerLookingGlassClient extends Viewer
// execute viewer process with arguments:
// in non-debug mode:
- // "looking-glass-client app:shmFile=<SHARED-MEM-FILE> win:fullScreen=yes spice:enable=yes spice:host=<SPICE-ADDRESS> spice:port=<SPICE-PORT> win:alerts=no"
+ // "looking-glass-client app:renderer=OpenGL app:shmFile=<SHARED-MEM-FILE> win:fullScreen=yes spice:enable=yes spice:host=<SPICE-ADDRESS> spice:port=<SPICE-PORT> win:alerts=no"
// in debug mode:
@@ -82,12 +82,13 @@ public class ViewerLookingGlassClient extends Viewer
// in debug mode:
- // "looking-glass-client app:shmFile=<SHARED-MEM-FILE> win:fullScreen=yes spice:enable=yes spice:host=<SPICE-ADDRESS> spice:port=<SPICE-PORT> win:alerts=yes win:showFPS=yes"
+ // "looking-glass-client app:renderer=OpenGL app:shmFile=<SHARED-MEM-FILE> win:fullScreen=yes spice:enable=yes spice:host=<SPICE-ADDRESS> spice:port=<SPICE-PORT> win:alerts=yes win:showFPS=yes"
final String[] viewerParameters;
if ( this.isDebugEnabled() ) {